/**
 * @file
 * Toggles the 'dark' class based on the selected dark mode.
 */

((Drupal, once) => {
  /**
   * Attaches behavior to toggle a class based on the selected dark mode.
   *
   * @type {Drupal~behavior}
   *
   * @prop {Drupal~behaviorAttach} attach
   *   Toggles the 'dark' class on the HTML element based on the selected dark
   *   mode.
   */
  Drupal.behaviors.darkModeToggle = {
    attach(context) {
      once('darkModeToggle', 'html', context).forEach(() => {
        context
          .querySelector('.dark-mode-toggle__button__light')
          .addEventListener('click', () => {
            // When the user explicitly chooses the light mode.
            localStorage.theme = 'light';
            document.documentElement.classList.remove('dark');
          });

        context
          .querySelector('.dark-mode-toggle__button__dark')
          .addEventListener('click', () => {
            // When the user explicitly chooses the dark mode.
            localStorage.theme = 'dark';
            document.documentElement.classList.add('dark');
          });

        context
          .querySelector('.dark-mode-toggle__button__system')
          .addEventListener('click', () => {
            // Whenever the user explicitly chooses to respect/switch back to the
            // OS preference.
            localStorage.removeItem('theme');
            document.documentElement.classList.toggle(
              'dark',
              window.matchMedia('(prefers-color-scheme: dark)').matches,
            );
          });
      });
    },
  };
})(Drupal, once);
